@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2014-10-28'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $DATE = '2014-10-30'; # DATE
+our $VERSION = '0.41'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -333,7 +333,8 @@ sub run_version {
           "\n",
           "  ", __PACKAGE__,
           " version ", ($Perinci::CmdLine::Lite::VERSION // "?"),
-          ($Perinci::CmdLine::Lite::DATE ? " ($Perinci::CmdLine::Lite::DATE)":''),
+          ($Perinci::CmdLine::Lite::DATE ?
+               " ($Perinci::CmdLine::Lite::DATE)":''),
       )];
 }
 
@@ -458,18 +459,19 @@ sub run_help {
             }
             my $arg = $sm->{arg};
             my $as = $args_p->{$arg};
-            my $alspec = $sm->{alias} ? $as->{cmdline_aliases}{$sm->{alias}} : {};
+            my $alspec = $sm->{alias} ?
+                $as->{cmdline_aliases}{$sm->{alias}} : {};
             my $sum = join(
                 "",
                 (defined($as->{pos}) ? "(or via arg #$as->{pos}".
                      ($as->{greedy} ? "+":"").") " : ""),
-                ($sm->{alias_for} ? $alspec->{summary} // "Alias for $sm->{alias_for}" :
-                     $as->{summary} // ''),
+                ($sm->{alias_for} ? $alspec->{summary} //
+                     "Alias for $sm->{alias_for}" : $as->{summary} // ''),
                 ($as->{cmdline_src} ? " ($as->{cmdline_src})" : ""),
             );
             my $sch = ($sm->{is_alias} ?
-                           $as->{cmdline_aliases}{$sm->{alias}}{schema} : undef) //
-                               $as->{schema};
+                           $as->{cmdline_aliases}{$sm->{alias}}{schema} :
+                               undef) // $as->{schema};
             if ($sch && $sch->[1]{in}) {
                 $sum .= " (".join("|", @{ $sch->[1]{in} }).")";
             }
@@ -497,6 +499,8 @@ sub run_call {
         $extra{args} = $r->{args};
     }
 
+    $extra{stream_arg} = 1 if $r->{stream_arg};
+
     $self->riap_client->request(
         call => $r->{subcommand_data}{url}, \%extra);
 }
@@ -516,7 +520,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.40 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2014-10-28.
+This document describes version 0.41 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2014-10-30.
 
 =head1 SYNOPSIS
 
